==> wiki3_5_4.zip: wiki3_5_4/plugin/bbs/BBS2List.pm <==
###############################################################################
#
# <p>bbs2ץ饰󤫤Ƥ줿ΰɽޤ</p>
# <pre>
# {{bbs2list ǼĤ̾,ɽ}}
# </pre>
# <p>
#  ɽά10鷺ɽޤ
#  ޤץǳƵΥȥΤɽ뤳ȤǤޤ
# </p>
# <pre>
# {{bbs2list ǼĤ̾,ɽ,title}}
# </pre>
# <p>
#  ξɽά뤳ȤǤޤά10鷺ɽޤ
# </p>
# <pre>
# {{bbs2list ǼĤ̾,title}}
# </pre>
#
###############################################################################
package plugin::bbs::BBS2List;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ΰ
#==============================================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $cgi    = $wiki->get_CGI();
	my $name   = shift;
	my $once   = shift;
	my $option = shift;
	my $title  = 0;
	
	# Υå
	if($name eq ""){
		return &Util::paragraph_error("ǼĤ̾ꤵƤޤ");
	}
	
	# ȥΤɽץ
	if($once eq "title" || $option eq "title"){
		$title = 1;
	}
	
	# ɽά줿
	if($once eq "" || !&Util::check_numeric($once)){
		$once = 10;
	}
	
	# WikiʸȤΩƤ
	my $i    = 0;
	my $buf  = "";
	my $page = $cgi->param("page");
	my $cnt  = $cgi->param("cnt");
	if($cnt eq ""){ $cnt = 0; };
	
	my @list = $self->_get_content_list($wiki,$name,$title);
	foreach my $item (@list){
		if($i >= $cnt*$once){
			if($title==1){
				$buf .= "*".$item->{name}."\n";
			} else {
				$buf .= "{{include ".$item->{name}."}}\n";
			}
		}
		$i++;
		last if($i/$once == $cnt+1);
	}
	
	# ڡѤΥ󥯤
	$buf .= "\n[ ";
	my $pagecnt = 1;
	for($i=0;$i<=$#list;$i=$i+$once){
		if($cnt==$pagecnt-1){
			$buf .= $pagecnt." ";
		} else {
			$buf .= "[$pagecnt|".$wiki->config('script_name')."?page=".&Util::url_encode($page).
			        "&amp;cnt=".($pagecnt-1)."] ";
		}
		$pagecnt++;
	}
	$buf .= "]\n";
	
	return $buf;
}

#==============================================================================
# ΰ
#==============================================================================
sub _get_content_list {
	my $self  = shift;
	my $wiki  = shift;
	my $name  = shift;
	my $title = shift;
	my @list  = ();
	my $qname = quotemeta($name);
	
	foreach my $pagename ($wiki->get_page_list()){
		if($pagename =~ /^BBS-$qname\/([0-9]+)$/){
			my $id = $1;
			if($title == 1){
				my $content = $wiki->get_page($pagename);
				if($content =~ /^!!(.*)$/m){
					my $subject = $1;
					push(@list,{name=>$subject,id=>$id});
				}
			} else {
				push(@list,{name=>$pagename,id=>$id});
			}
		}
	}
	@list = sort { $b->{id} <=> $a->{id} } @list;
	return @list;
}

1;

==> wiki3_5_7dev2.zip: wiki3_5_7dev2/plugin/bbs/BBS2List.pm <==
###############################################################################
#
# <p>bbs2ץ饰󤫤Ƥ줿ΰɽޤ</p>
# <pre>
# {{bbs2list ǼĤ̾,ɽ}}
# </pre>
# <p>
#  ɽά10鷺ɽޤ
#  ޤץǳƵΥȥΤɽ뤳Ȥ䡢
#  ɽ뤳ȤǤޤ
# </p>
# <pre>
# {{bbs2list ǼĤ̾,ɽ,title}}
# </pre>
# <p>
#  ξɽά뤳ȤǤޤά10鷺ɽޤ
# </p>
# <pre>
# {{bbs2list ǼĤ̾,title}}
# </pre>
# <p>
#  recentϡ򹹿ɽޤʥåɡեȷ
#  titlerecentϤɤ˻ꤷƤɤǤ
#  2ĤΥץϤ줾Ω˺Ѥޤ
# </p>
# <pre>
# {{bbs2list ǼĤ̾,ɽ,recent,title}}
# {{bbs2list ǼĤ̾,title,recent}}
# </pre>
#
###############################################################################
package plugin::bbs::BBS2List;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ΰ
#==============================================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $cgi    = $wiki->get_CGI();
	my $name   = shift;
	
	# Υå
	if($name eq ""){
		return &Util::paragraph_error("ǼĤ̾ꤵƤޤ");
	}
	
	# 2ܤΰäϤɽˤ롣
	my $once = &Util::trim($_[0]);
	$once = &Util::check_numeric($once) ? $once : 10;
	
	# ĤΥץ
	my %option;
	undef %option;
	$option{lc &Util::trim($_)} = 1 foreach @_;
	my $title  = exists $option{'title'}  ? 1 : 0;
	my $recent = exists $option{'recent'} ? 1 : 0;

	
	# WikiʸȤΩƤ
	my $i    = 0;
	my $buf  = "";
	my $page = $cgi->param("page");
	my $cnt  = $cgi->param("cnt");
	if($cnt eq ""){ $cnt = 0; };
	
	my $ref_list = $self->_get_content_list($wiki,$name,$title,$recent);
	foreach my $item (@$ref_list){
		if($i >= $cnt*$once){
			if($title){
				$buf .= "*".$item->{name}."\n";
			} else {
				$buf .= "{{include ".$item->{name}."}}\n";
			}
		}
		$i++;
		last if($i/$once == $cnt+1);
	}
	
	# ڡѤΥ󥯤
	$buf .= "\n[ ";
	my $pagecnt = 1;
	for($i=0;$i<=$#$ref_list;$i=$i+$once){
		if($cnt==$pagecnt-1){
			$buf .= $pagecnt." ";
		} else {
			$buf .= "[$pagecnt|".$wiki->config('script_name')."?page=".&Util::url_encode($page).
			        "&amp;cnt=".($pagecnt-1)."] ";
		}
		$pagecnt++;
	}
	$buf .= "]\n";
	
	return $buf;
}

#==============================================================================
# ΰ
#==============================================================================
sub _get_content_list {
	my $self   = shift;
	my $wiki   = shift;
	my $name   = shift;
	my $title  = shift;
	my $recent = shift;
	my @list  = ();
	my $qname = quotemeta($name);
	
	foreach my $pagename ($wiki->get_page_list()){
		if($pagename =~ /^BBS-$qname\/([0-9]+)$/){
			my $id = $1;
			if($title){
				my $content = $wiki->get_page($pagename);
				if($content =~ /^!!(.*)$/m){
					push(@list,{name=>$1,id=>$id});
				}
			} else {
				push(@list,{name=>$pagename,id=>$id});
			}
		}
	}
	
	if($recent){
		# ƥåɤι
		foreach (@list) {
			$_->{last_modified} = $wiki->get_last_modified2("BBS-$name/$_->{id}");
		}
		# ʿˤ˥
		@list = sort { $b->{last_modified} <=> $a->{last_modified} } @list;
	} else {
		# recentλ꤬ʤȤidʥåΩƤ֡ˤι߽
		@list = sort { $b->{id} <=> $a->{id} } @list;
	}
	
	return \@list;
}

1;
